@@ -3,16 +3,20 @@
 #' Estimation of model parameters and probability of informed trading for quarterly data.
 #'
 #' Wrapper around \code{\link{pin_est}} function and therefore inherits its settings for optimization.
-#' Data is splitted into quarters with the \code{\link[lubridate]{quarter}} function from \pkg{lubridate} package.
+#' Data is split into quarters with the \code{\link[lubridate]{quarter}} function from \pkg{lubridate} package.
 #' According to the help page of this function \code{dates} argument must be \cr
 #' \emph{a date-time object of class POSIXct, POSIXlt, Date, chron, yearmon, yearqtr, zoo, zooreg,
 #'  timeDate, xts, its, ti, jul, timeSeries, fts or anything else that can be converted with as.POSIXlt}. \cr
-#' \code{\link{nlminb}} function in the \pkg{stats} package is used for maximization. 
-#' Vectors for \code{numbuys} and \code{numsells} need to have same length. 
+#' \code{\link{nlminb}} function in the \pkg{stats} package is used for maximization.
+#' Vectors for \code{numbuys} and \code{numsells} need to have same length. \cr
+#' Calculation of confidence interval for the probability of informed trading is disabled by default.
+#' For more details see \code{\link{pin_est_core}}
 #'
 #' @param dates see \strong{Details}
 #' @inheritParams pin_ll
 #' @inheritParams pin_est_core
+#' @inheritParams pin_confint
+#' @param ci_control \emph{list} see \code{\link{pin_est_core}}
 #'
 #' @seealso \code{\link{nlminb}},
 #'          \code{\link{initial_vals}}
@@ -34,6 +38,7 @@
 #'  \item{message}{Convergence message returned by the nlminb optimizer}
 #'  \item{iterations}{Number of iterations until convergence of nlminb optimizer}
 #'  \item{init_vals}{Vector of initial values}
+#'  \item{confint}{If \code{confint = TRUE}; confidence interval for the probability of informed trading}
 #'  }
 #'
 #' @references
@@ -49,7 +54,7 @@
 #'
 #' Easley, David et al. (2010) \cr
 #' Factoring Information into Returns \cr
-#' \emph{Journal of Financial and Quantitative Analysis}, Volume 45, Issue 2, pp. 293 - 309
+#' \emph{Journal of Financial and Quantitative Analysis}, Volume 45, Issue 2, pp. 293 - 309 \cr
 #' \doi{10.1017/S0022109010000074}
 #'
 #' Ersan, Oguz and Alici, Asli (2016) \cr
@@ -62,16 +67,17 @@
 #' using hierarchical agglomerative clustering \cr
 #' \emph{Quantitative Finance}, Volume 15, Issue 11, pp. 1805 - 1821 \cr
 #' \doi{10.1080/14697688.2015.1023336}
-#' 
+#'
+#' Grolemund, Garett and Wickham, Hadley (2011) \cr
+#' Dates and Times Made Easy with lubridate \cr
+#' \emph{Journal of Statistical Software}, Volume 40, Issue 3, pp. 1 - 25 \cr
+#' \doi{10.18637/jss.v040.i03}
+#'
 #' Lin, Hsiou-Wei William and Ke, Wen-Chyan (2011) \cr
 #' A computing bias in estimating the probability of informed trading \cr
 #' \emph{Journal of Financial Markets}, Volume 14, Issue 4, pp. 625 - 640 \cr
 #' \doi{10.1016/j.finmar.2011.03.001}
 #'
-#' Grolemund, Garett and Wickham, Hadley (2011) \cr
-#' Dates and Times Made Easy with lubridate \cr
-#' \emph{Journal of Statistical Software}, Volume 40, Issue 3, pp. 1 - 25
-#'
 #' Yan, Yuxing and Zhang, Shaojun (2012) \cr
 #' An improved estimation method and empirical properties of the probability of informed trading \cr
 #' \emph{Journal of Banking & Finance}, Volume 36, Issue 2, pp. 454 - 467 \cr
@@ -79,12 +85,12 @@
 #'
 #' @examples
 #' # Loading one year of simulated daily buys and sells
-#' 
+#'
 #' data('BSfrequent2015')
-#' 
+#'
 #' # Quarterly estimates for model parameters and the probability of informed trading
 #' # Rownames of 'BSfrequent2015' equal the business days in 2015.
-#' 
+#'
 #' qpin2015 <- qpin(numbuys = BSfrequent2015[,"Buys"],
 #'                  numsells = BSfrequent2015[,"Sells"],
 #'                  dates = as.Date(rownames(BSfrequent2015), format = "%Y-%m-%d"))
@@ -92,7 +98,8 @@
 #' @export
 
 qpin <- function(numbuys = NULL, numsells = NULL, dates = NULL,
-                 lower = rep(0,5), upper = c(1,1,rep(Inf,3))) {
+                 lower = rep(0,5), upper = c(1,1,rep(Inf,3)),
+                 confint = FALSE, ci_control = list()) {
   if(is.null(numbuys)) stop("Missing data for 'numbuys'")
   if(is.null(numsells)) stop("Missing data for 'numsells'")
   if(is.null(dates)) stop("Missing 'dates'")
@@ -126,10 +133,7 @@ qpin <- function(numbuys = NULL, numsells = NULL, dates = NULL,
 
   res <- lapply(quarter_list,
                 function(x) pin_est(numbuys = x[,1], numsells = x[,2],
-                                    lower = lower, upper = upper))
+                                    lower = lower, upper = upper,
+                                    confint = confint, ci_control = ci_control))
   res
 }
-
-
-
-
